# Open Data Discovery models package

Models automatically generated by `datamodel-code-generator` from [ODD OpenApi specification](https://github.com/opendatadiscovery/opendatadiscovery-specification)


## Usage example:
```python
from odd_models.models import DataEntityList

data_entity_list = DataEntityList(data_source_oddrn='/postgresql/host/localhost/databases/opendatadiscovery', items=[])
```